@@ -7,10 +7,10 @@ from ._keys import (
     KeySetSerialization,
 )
 from ._rfc7517.types import AnyKey, DictKey, KeyParameters
-from ._rfc7518.oct_key import OctKey as OctKey
-from ._rfc7518.rsa_key import RSAKey as RSAKey
-from ._rfc7518.ec_key import ECKey as ECKey
-from ._rfc8037.okp_key import OKPKey as OKPKey
+from ._rfc7518.oct_key import OctKey
+from ._rfc7518.rsa_key import RSAKey
+from ._rfc7518.ec_key import ECKey
+from ._rfc8037.okp_key import OKPKey
 from ._rfc8812 import register_secp256k1
 from ._rfc7638 import calculate_thumbprint as thumbprint
 from ._rfc9278 import calculate_thumbprint_uri as thumbprint_uri
